@@ -1,19 +1,39 @@
 
 package MooseX::AttributeHelpers::Collection::Bag;
 use Moose;
+use Moose::Util::TypeConstraints;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Collection::Bag';
+use MooseX::AttributeHelpers::MethodProvider::Bag;
+
+extends 'MooseX::AttributeHelpers::Collection';
+
+has '+method_provider' => (
+    default => 'MooseX::AttributeHelpers::MethodProvider::Bag'
+);
+
+subtype 'Bag' => as 'HashRef[Int]';
+
+sub helper_type { 'Bag' }
+
+before 'process_options_for_provides' => sub {
+    my ($self, $options, $name) = @_;
+
+    # Set some default attribute options here unless already defined
+    if ((my $type = $self->helper_type) && !exists $options->{isa}){
+        $options->{isa} = $type;
+    }
+    
+    $options->{default} = sub { +{} } unless exists $options->{default};
+};
 
 no Moose;
+no Moose::Util::TypeConstraints;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Collection::Bag;
+package Moose::Meta::Attribute::Custom::Collection::Bag;
 sub register_implementation { 'MooseX::AttributeHelpers::Collection::Bag' }
 
 1;
@@ -79,11 +99,11 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
