@@ -2,18 +2,23 @@
 package MooseX::AttributeHelpers::Collection::ImmutableHash;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Collection::ImmutableHash';
+use MooseX::AttributeHelpers::MethodProvider::ImmutableHash;
+
+extends 'MooseX::AttributeHelpers::Collection';
+
+has '+method_provider' => (
+    default => 'MooseX::AttributeHelpers::MethodProvider::ImmutableHash'
+);
+
+sub helper_type { 'HashRef' }
 
 no Moose;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Collection::ImmutableHash;
+package Moose::Meta::Attribute::Custom::Collection::ImmutableHash;
 sub register_implementation { 'MooseX::AttributeHelpers::Collection::ImmutableHash' }
 
 
@@ -77,11 +82,11 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
