@@ -2,7 +2,7 @@
 package MooseX::AttributeHelpers::Counter;
 use Moose;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use MooseX::AttributeHelpers::MethodProvider::Counter;
@@ -14,7 +14,33 @@ has '+method_provider' => (
 );
 
 sub helper_type { 'Num' }
+
+before 'process_options_for_provides' => sub {
+    my ($self, $options, $name) = @_;
+
+    # Set some default attribute options here unless already defined
+    if ((my $type = $self->helper_type) && !exists $options->{isa}){
+        $options->{isa} = $type;
+    }
     
+    $options->{is}      = 'ro' unless exists $options->{is};
+    $options->{default} = 0    unless exists $options->{default};
+};
+
+after 'check_provides_values' => sub {
+    my $self     = shift;
+    my $provides = $self->provides;
+
+    unless (scalar keys %$provides) {
+        my $method_constructors = $self->method_constructors;
+        my $attr_name           = $self->name;
+        
+        foreach my $method (keys %$method_constructors) {
+            $provides->{$method} = ($method . '_' . $attr_name);
+        }
+    }
+};
+
 no Moose;
 
 # register the alias ...
@@ -39,12 +65,13 @@ MooseX::AttributeHelpers::Counter
   
   has 'counter' => (
       metaclass => 'Counter',
-      is        => 'rw',
-      isa       => 'Int',
+      is        => 'ro',
+      isa       => 'Num',
       default   => sub { 0 },
       provides  => {
           inc => 'inc_counter',
           dec => 'dec_counter',          
+          reset => 'reset_counter',
       }
   );
 
@@ -57,16 +84,34 @@ MooseX::AttributeHelpers::Counter
 This module provides a simple counter attribute, which can be 
 incremented and decremeneted. 
 
+If your attribute definition does not include any of I<is>, I<isa>,
+I<default> or I<provides> but does use the C<Counter> metaclass,
+then this module applies defaults as in the L</SYNOPSIS>
+above. This allows for a very basic counter definition:
+
+  has 'foo' => (metaclass => 'Counter');
+  $obj->inc_foo;
+
 =head1 METHODS
 
 =over 4
 
+=item B<meta>
+
 =item B<method_provider>
 
 =item B<has_method_provider>
 
 =item B<helper_type>
 
+=item B<process_options_for_provides>
+
+Run before its superclass method.
+
+=item B<check_provides_values>
+
+Run after its superclass method.
+
 =back
 
 =head1 PROVIDED METHODS
@@ -109,4 +154,4 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
