@@ -1,60 +1,47 @@
 package MooseX::AttributeHelpers::MethodProvider::ImmutableHash;
 use Moose::Role;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub exists : method {
-    my ($attr, $reader, $writer) = @_;
+    my ($attr, $reader, $writer) = @_;    
     return sub { CORE::exists $reader->($_[0])->{$_[1]} ? 1 : 0 };
-}
-
-sub defined : method {
-    my ($attr, $reader, $writer) = @_;
-    return sub { CORE::defined $reader->($_[0])->{$_[1]} ? 1 : 0 };
-}
+}   
 
 sub get : method {
-    my ($attr, $reader, $writer) = @_;
-    return sub {
-        if ( @_ == 2 ) {
-            $reader->($_[0])->{$_[1]}
-        } else {
-            my ( $self, @keys ) = @_;
-            @{ $reader->($self) }{@keys}
-        }
-    };
+    my ($attr, $reader, $writer) = @_;    
+    return sub { $reader->($_[0])->{$_[1]} };
 }
 
 sub keys : method {
     my ($attr, $reader, $writer) = @_;
-    return sub { CORE::keys %{$reader->($_[0])} };
+    return sub { CORE::keys %{$reader->($_[0])} };        
 }
-
+     
 sub values : method {
     my ($attr, $reader, $writer) = @_;
-    return sub { CORE::values %{$reader->($_[0])} };
-}
+    return sub { CORE::values %{$reader->($_[0])} };        
+}   
 
 sub kv : method {
     my ($attr, $reader, $writer) = @_;
-    return sub {
+    return sub { 
         my $h = $reader->($_[0]);
         map {
             [ $_, $h->{$_} ]
-        } CORE::keys %{$h}
-    };
+        } CORE::keys %{$h} 
+    };    
 }
-
+   
 sub count : method {
     my ($attr, $reader, $writer) = @_;
-    return sub { scalar CORE::keys %{$reader->($_[0])} };
+    return sub { scalar CORE::keys %{$reader->($_[0])} };        
 }
 
 sub empty : method {
     my ($attr, $reader, $writer) = @_;
-    return sub { scalar CORE::keys %{$reader->($_[0])} ? 1 : 0 };
+    return sub { scalar CORE::keys %{$reader->($_[0])} ? 1 : 0 };        
 }
 
 1;
@@ -66,10 +53,10 @@ __END__
 =head1 NAME
 
 MooseX::AttributeHelpers::MethodProvider::ImmutableHash
-
+  
 =head1 DESCRIPTION
 
-This is a role which provides the method generators for
+This is a role which provides the method generators for 
 L<MooseX::AttributeHelpers::Collection::ImmutableHash>.
 
 =head1 METHODS
@@ -86,41 +73,23 @@ L<MooseX::AttributeHelpers::Collection::ImmutableHash>.
 
 =item B<count>
 
-Returns the number of elements in the list.
-
 =item B<empty>
 
-If the list is populated, returns true. Otherwise, returns false.
-
 =item B<exists>
 
-Returns true if the given key is present in the hash
-
-=item B<defined>
-
-Returns true if the value of a given key is defined
-
 =item B<get>
 
-Returns an element of the hash by its key.
-
 =item B<keys>
 
-Returns the list of keys in the hash.
-
 =item B<values>
 
-Returns the list of values in the hash.
-
 =item B<kv>
 
-Returns the  key, value pairs in the hash
-
 =back
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
+All complex software has bugs lurking in it, and this module is no 
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -130,7 +99,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
